@@ -22,12 +22,12 @@
 #'        When creating a table for the first time \code{s3.location} will be formatted from \code{"s3://mybucket/data/"} to the following
 #'        syntax \code{"s3://{mybucket/data}/{schema}/{table}/{parition}/"} this is to support tables with the same name but existing in different
 #'        schemas. If schema isn't specified in \code{name} parameter then the schema from \code{dbConnect} is used instead.
-#' @param file.type What file type to store data.frame on s3, noctua currently supports ["tsv", "csv", "parquet", "json"]. Default delimited file type is "tsv", in previous versions
+#' @param file.type What file type to store data.frame on s3, noctua currently supports \code{c("tsv", "csv", "parquet", "json")}. Default delimited file type is "tsv", in previous versions
 #'                  of \code{noctua (=< 1.4.0)} file type "csv" was used as default. The reason for the change is that columns containing \code{Array/JSON} format cannot be written to
 #'                  Athena due to the separating value ",". This would cause issues with AWS Athena.
 #'                  \strong{Note:} "parquet" format is supported by the \code{arrow} package and it will need to be installed to utilise the "parquet" format.
 #'                  "json" format is supported by \code{jsonlite} package and it will need to be installed to utilise the "json" format.
-#' @param compress \code{FALSE | TRUE} To determine if to compress file.type. If file type is ["csv", "tsv"] then "gzip" compression is used, for file type "parquet"
+#' @param compress \code{FALSE | TRUE} To determine if to compress file.type. If file type is \code{c("csv", "tsv")} then "gzip" compression is used, for file type "parquet"
 #'                 "snappy" compression is used. Currently \code{noctua} doesn't support compression for "json" file type.
 #' @param max.batch Split the data frame by max number of rows i.e. 100,000 so that multiple files can be uploaded into AWS S3. By default when compression
 #'                  is set to \code{TRUE} and file.type is "csv" or "tsv" max.batch will split data.frame into 20 batches. This is to help the
@@ -86,10 +86,21 @@
 NULL
 
 Athena_write_table <-
-  function(conn, name, value, overwrite = FALSE, append = FALSE,
-           row.names = NA, field.types = NULL,
-           partition = NULL, s3.location = NULL, file.type = c("tsv", "csv", "parquet", "json"),
-           compress = FALSE, max.batch = Inf, ...) {
+  function(
+    conn,
+    name,
+    value,
+    overwrite = FALSE,
+    append = FALSE,
+    row.names = NA,
+    field.types = NULL,
+    partition = NULL,
+    s3.location = NULL,
+    file.type = c("tsv", "csv", "parquet", "json"),
+    compress = FALSE,
+    max.batch = Inf,
+    ...
+  ) {
     # variable checks
     stopifnot(
       is.character(name),
@@ -103,21 +114,36 @@ Athena_write_table <-
 
     sapply(tolower(names(partition)), function(x) {
       if (x %in% tolower(names(value))) {
-        stop("partition ", x, " is a variable in data.frame ", deparse(substitute(value)), call. = FALSE)
+        stop(
+          "partition ",
+          x,
+          " is a variable in data.frame ",
+          deparse(substitute(value)),
+          call. = FALSE
+        )
       }
     })
 
     file.type <- match.arg(file.type)
 
-    if (max.batch < 0) stop("`max.batch` has to be greater than 0", call. = F)
+    if (max.batch < 0) {
+      stop("`max.batch` has to be greater than 0", call. = F)
+    }
 
     # use default s3_staging directory is s3.location isn't provided
-    if (is.null(s3.location)) s3.location <- conn@info$s3_staging
+    if (is.null(s3.location)) {
+      s3.location <- conn@info$s3_staging
+    }
 
     # made everything lower case due to aws Athena issue: https://aws.amazon.com/premiumsupport/knowledge-center/athena-aws-glue-msck-repair-table/
     name <- tolower(name)
     s3.location <- tolower(s3.location)
-    if (!is.null(partition) && is.null(names(partition))) stop("partition parameter requires to be a named vector or list", call. = FALSE)
+    if (!is.null(partition) && is.null(names(partition))) {
+      stop(
+        "partition parameter requires to be a named vector or list",
+        call. = FALSE
+      )
+    }
     if (!is.null(partition)) {
       names(partition) <- tolower(names(partition))
     }
@@ -125,20 +151,30 @@ Athena_write_table <-
     ll <- db_detect(conn, name)
     db_name <- paste(ll, collapse = ".")
 
-    if (overwrite && append) stop("overwrite and append cannot both be TRUE", call. = FALSE)
+    if (overwrite && append) {
+      stop("overwrite and append cannot both be TRUE", call. = FALSE)
+    }
 
     # Check if table already exists in the database
     found <- dbExistsTable(conn, db_name)
 
     if (found && !overwrite && !append) {
-      stop("Table ", db_name, " exists in database, and both overwrite and",
+      stop(
+        "Table ",
+        db_name,
+        " exists in database, and both overwrite and",
         " append are FALSE",
         call. = FALSE
       )
     }
 
     if (!found && append) {
-      stop("Table ", db_name, " does not exist in database and append is set to TRUE", call. = FALSE)
+      stop(
+        "Table ",
+        db_name,
+        " does not exist in database and append is set to TRUE",
+        call. = FALSE
+      )
     }
 
     if (found && overwrite) {
@@ -156,9 +192,11 @@ Athena_write_table <-
       )
 
       # Return correct file format when appending onto existing AWS Athena table
-      File.Type <- switch(tbl_info$Parameters$serde.serialization.lib,
+      File.Type <- switch(
+        tbl_info$Parameters$serde.serialization.lib,
         "org.apache.hadoop.hive.serde2.lazy.LazySimpleSerDe" = {
-          switch(tbl_info$Parameters$serde.param.field.delim,
+          switch(
+            tbl_info$Parameters$serde.param.field.delim,
             "," = "csv",
             "\t" = "tsv",
             stop("noctua currently only supports csv and tsv delimited format")
@@ -168,14 +206,19 @@ Athena_write_table <-
         # json library support: https://docs.aws.amazon.com/athena/latest/ug/json.html#hivejson
         "org.apache.hive.hcatalog.data.JsonSerDe" = "json",
         "org.openx.data.jsonserde.JsonSerDe" = "json",
-        stop("Unable to append onto table: ", db_name, "\n", tbl_info$Parameters$serde.serialization.lib,
+        stop(
+          "Unable to append onto table: ",
+          db_name,
+          "\n",
+          tbl_info$Parameters$serde.serialization.lib,
           ": Is currently not supported by noctua",
           call. = F
         )
       )
 
       # Return if existing files are compressed or not
-      compress <- switch(File.Type,
+      compress <- switch(
+        File.Type,
         "parquet" = {
           if (is.null(tbl_info$Parameters$parquet.compress)) {
             FALSE
@@ -183,7 +226,10 @@ Athena_write_table <-
             if (tolower(tbl_info$Parameters$parquet.compress) == "snappy") {
               TRUE
             } else {
-              stop("noctua currently only supports SNAPPY compression for parquet", call. = F)
+              stop(
+                "noctua currently only supports SNAPPY compression for parquet",
+                call. = F
+              )
             }
           }
         },
@@ -194,7 +240,10 @@ Athena_write_table <-
             if (tolower(tbl_info$Parameters$compressionType) == "gzip") {
               TRUE
             } else {
-              stop("noctua currently only supports gzip compression for tsv", call. = F)
+              stop(
+                "noctua currently only supports gzip compression for tsv",
+                call. = F
+              )
             }
           }
         },
@@ -205,7 +254,10 @@ Athena_write_table <-
             if (tolower(tbl_info$Parameters$compressionType) == "gzip") {
               TRUE
             } else {
-              stop("noctua currently only supports gzip compression for csv", call. = F)
+              stop(
+                "noctua currently only supports gzip compression for csv",
+                call. = F
+              )
             }
           }
         },
@@ -214,7 +266,10 @@ Athena_write_table <-
             FALSE
           } else {
             if (!is.null(tbl_info$Parameters$compressionType)) {
-              stop("noctua currently doesn't support compression for json", call. = F)
+              stop(
+                "noctua currently doesn't support compression for json",
+                call. = F
+              )
             }
           }
         }
@@ -222,7 +277,9 @@ Athena_write_table <-
       if (file.type != File.Type) {
         warning(
           "Appended `file.type` is not compatible with the existing Athena DDL",
-          ' file type and has been converted to "', File.Type, '".',
+          ' file type and has been converted to "',
+          File.Type,
+          '".',
           call. = FALSE
         )
       }
@@ -233,7 +290,9 @@ Athena_write_table <-
     }
 
     # return original Athena Types
-    if (is.null(field.types)) field.types <- dbDataType(conn, value)
+    if (is.null(field.types)) {
+      field.types <- dbDataType(conn, value)
+    }
     value <- sqlData(conn, value, row.names = row.names, file.type = file.type)
 
     ############# write data frame to file type ###########################
@@ -264,13 +323,26 @@ Athena_write_table <-
     ############# update data to aws s3 ###########################
 
     # send data over to s3 bucket
-    upload_data(conn, FileLocation, db_name, partition, s3.location, file.type, compress, append)
+    upload_data(
+      conn,
+      FileLocation,
+      db_name,
+      partition,
+      s3.location,
+      file.type,
+      compress,
+      append
+    )
 
     if (!append) {
-      sql <- sqlCreateTable(conn,
-        table = db_name, fields = value, field.types = field.types,
+      sql <- sqlCreateTable(
+        conn,
+        table = db_name,
+        fields = value,
+        field.types = field.types,
         partition = names(partition),
-        s3.location = s3.location, file.type = file.type,
+        s3.location = s3.location,
+        file.type = file.type,
         compress = compress
       )
       # create Athena table
@@ -291,14 +363,16 @@ Athena_write_table <-
   }
 
 # send data to s3 is Athena registered location
-upload_data <- function(conn,
-                        x,
-                        name,
-                        partition = NULL,
-                        s3.location = NULL,
-                        file.type = NULL,
-                        compress = NULL,
-                        append = FALSE) {
+upload_data <- function(
+  conn,
+  x,
+  name,
+  partition = NULL,
+  s3.location = NULL,
+  file.type = NULL,
+  compress = NULL,
+  append = FALSE
+) {
   # create s3 location components
   s3_location <- s3_upload_location(conn, s3.location, name, partition, append)
 
@@ -315,7 +389,11 @@ upload_data <- function(conn,
 
   for (i in seq_along(x)) {
     obj <- readBin(x[i], "raw", n = file.size(x[i]))
-    retry_api_call(conn@ptr$S3$put_object(Body = obj, Bucket = Bucket, Key = s3_key[i]))
+    retry_api_call(conn@ptr$S3$put_object(
+      Body = obj,
+      Bucket = Bucket,
+      Key = s3_key[i]
+    ))
   }
 
   invisible(NULL)
@@ -325,16 +403,37 @@ upload_data <- function(conn,
 #' @inheritParams DBI::dbWriteTable
 #' @export
 setMethod(
-  "dbWriteTable", c("AthenaConnection", "character", "data.frame"),
-  function(conn, name, value, overwrite = FALSE, append = FALSE,
-           row.names = NA, field.types = NULL,
-           partition = NULL, s3.location = NULL, file.type = c("tsv", "csv", "parquet", "json"),
-           compress = FALSE, max.batch = Inf, ...) {
+  "dbWriteTable",
+  c("AthenaConnection", "character", "data.frame"),
+  function(
+    conn,
+    name,
+    value,
+    overwrite = FALSE,
+    append = FALSE,
+    row.names = NA,
+    field.types = NULL,
+    partition = NULL,
+    s3.location = NULL,
+    file.type = c("tsv", "csv", "parquet", "json"),
+    compress = FALSE,
+    max.batch = Inf,
+    ...
+  ) {
     con_error_msg(conn, msg = "Connection already closed.")
     Athena_write_table(
-      conn, name, value, overwrite, append,
-      row.names, field.types,
-      partition, s3.location, file.type, compress, max.batch
+      conn,
+      name,
+      value,
+      overwrite,
+      append,
+      row.names,
+      field.types,
+      partition,
+      s3.location,
+      file.type,
+      compress,
+      max.batch
     )
   }
 )
@@ -342,17 +441,38 @@ setMethod(
 #' @rdname AthenaWriteTables
 #' @export
 setMethod(
-  "dbWriteTable", c("AthenaConnection", "Id", "data.frame"),
-  function(conn, name, value, overwrite = FALSE, append = FALSE,
-           row.names = NA, field.types = NULL,
-           partition = NULL, s3.location = NULL, file.type = c("tsv", "csv", "parquet", "json"),
-           compress = FALSE, max.batch = Inf, ...) {
+  "dbWriteTable",
+  c("AthenaConnection", "Id", "data.frame"),
+  function(
+    conn,
+    name,
+    value,
+    overwrite = FALSE,
+    append = FALSE,
+    row.names = NA,
+    field.types = NULL,
+    partition = NULL,
+    s3.location = NULL,
+    file.type = c("tsv", "csv", "parquet", "json"),
+    compress = FALSE,
+    max.batch = Inf,
+    ...
+  ) {
     con_error_msg(conn, msg = "Connection already closed.")
     name <- db_quote_identifier(name)
     Athena_write_table(
-      conn, name, value, overwrite, append,
-      row.names, field.types,
-      partition, s3.location, file.type, compress, max.batch
+      conn,
+      name,
+      value,
+      overwrite,
+      append,
+      row.names,
+      field.types,
+      partition,
+      s3.location,
+      file.type,
+      compress,
+      max.batch
     )
   }
 )
@@ -360,16 +480,37 @@ setMethod(
 #' @rdname AthenaWriteTables
 #' @export
 setMethod(
-  "dbWriteTable", c("AthenaConnection", "SQL", "data.frame"),
-  function(conn, name, value, overwrite = FALSE, append = FALSE,
-           row.names = NA, field.types = NULL,
-           partition = NULL, s3.location = NULL, file.type = c("tsv", "csv", "parquet", "json"),
-           compress = FALSE, max.batch = Inf, ...) {
+  "dbWriteTable",
+  c("AthenaConnection", "SQL", "data.frame"),
+  function(
+    conn,
+    name,
+    value,
+    overwrite = FALSE,
+    append = FALSE,
+    row.names = NA,
+    field.types = NULL,
+    partition = NULL,
+    s3.location = NULL,
+    file.type = c("tsv", "csv", "parquet", "json"),
+    compress = FALSE,
+    max.batch = Inf,
+    ...
+  ) {
     con_error_msg(conn, msg = "Connection already closed.")
     Athena_write_table(
-      conn, name, value, overwrite, append,
-      row.names, field.types,
-      partition, s3.location, file.type, compress, max.batch
+      conn,
+      name,
+      value,
+      overwrite,
+      append,
+      row.names,
+      field.types,
+      partition,
+      s3.location,
+      file.type,
+      compress,
+      max.batch
     )
   }
 )
@@ -379,7 +520,7 @@ setMethod(
 #' This method converts data.frame columns into the correct format so that it can be uploaded Athena.
 #' @name sqlData
 #' @inheritParams DBI::sqlData
-#' @param file.type What file type to store data.frame on s3, noctua currently supports ["csv", "tsv", "parquet", "json"].
+#' @param file.type What file type to store data.frame on s3, noctua currently supports `c("csv", "tsv", "parquet", "json")`.
 #'                  \strong{Note:} This parameter is used for format any special characters that clash with file type separator.
 #' @return \code{sqlData} returns a dataframe formatted for Athena. Currently converts \code{list} variable types into \code{character}
 #'         split by \code{'|'}, similar to how \code{data.table} writes out to files.
@@ -389,8 +530,15 @@ NULL
 #' @rdname sqlData
 #' @export
 setMethod(
-  "sqlData", "AthenaConnection",
-  function(con, value, row.names = NA, file.type = c("tsv", "csv", "parquet", "json"), ...) {
+  "sqlData",
+  "AthenaConnection",
+  function(
+    con,
+    value,
+    row.names = NA,
+    file.type = c("tsv", "csv", "parquet", "json"),
+    ...
+  ) {
     stopifnot(is.data.frame(value))
     file.type <- match.arg(file.type)
     Value <- copy(value)
@@ -398,32 +546,62 @@ setMethod(
     field_names <- gsub("\\.", "_", make.names(names(Value), unique = TRUE))
     DIFF <- setdiff(field_names, names(Value))
     names(Value) <- field_names
-    if (length(DIFF) > 0) info_msg("data.frame colnames have been converted to align with Athena DDL naming convertions: \n", paste0(DIFF, collapse = ",\n"))
+    if (length(DIFF) > 0) {
+      info_msg(
+        "data.frame colnames have been converted to align with Athena DDL naming convertions: \n",
+        paste0(DIFF, collapse = ",\n")
+      )
+    }
     # get R col types
     col_types <- sapply(Value, class)
 
     # leave POSIXct format for parquet file types
     if (file.type != "parquet") {
       # preprocessing POSIXct format
-      posixct_cols <- names(Value)[sapply(col_types, function(x) "POSIXct" %in% x)]
+      posixct_cols <- names(Value)[sapply(col_types, function(x) {
+        "POSIXct" %in% x
+      })]
       # create timestamp in athena format: https://docs.aws.amazon.com/athena/latest/ug/data-types.html
-      for (col in posixct_cols) set(Value, j = col, value = strftime(Value[[col]], format = "%Y-%m-%d %H:%M:%OS3", tz = con@info$timezone))
+      for (col in posixct_cols) {
+        set(
+          Value,
+          j = col,
+          value = strftime(
+            Value[[col]],
+            format = "%Y-%m-%d %H:%M:%OS3",
+            tz = con@info$timezone
+          )
+        )
+      }
     }
 
     # preprocessing list format
     list_cols <- names(Value)[sapply(col_types, function(x) "list" %in% x)]
-    for (col in list_cols) set(Value, j = col, value = col_to_ndjson(Value, col))
+    for (col in list_cols) {
+      set(Value, j = col, value = col_to_ndjson(Value, col))
+    }
 
     # handle special characters in character and factor column types
     special_char <- names(Value)[col_types %in% c("character", "factor")]
-    switch(file.type,
-      csv = { # changed special character from "," to "." to avoid issue with parsing delimited files
-        for (col in special_char) set(Value, j = col, value = gsub(",", "\\.", Value[[col]]))
-        info_msg("Special character \",\" has been converted to \".\" to help with Athena reading file format csv")
+    switch(
+      file.type,
+      csv = {
+        # changed special character from "," to "." to avoid issue with parsing delimited files
+        for (col in special_char) {
+          set(Value, j = col, value = gsub(",", "\\.", Value[[col]]))
+        }
+        info_msg(
+          "Special character \",\" has been converted to \".\" to help with Athena reading file format csv"
+        )
       },
-      tsv = { # changed special character from "\t" to " " to avoid issue with parsing delimited files
-        for (col in special_char) set(Value, j = col, value = gsub("\t", " ", Value[[col]]))
-        info_msg("Special characters \"\\t\" has been converted to \" \" to help with Athena reading file format tsv")
+      tsv = {
+        # changed special character from "\t" to " " to avoid issue with parsing delimited files
+        for (col in special_char) {
+          set(Value, j = col, value = gsub("\t", " ", Value[[col]]))
+        }
+        info_msg(
+          "Special characters \"\\t\" has been converted to \" \" to help with Athena reading file format tsv"
+        )
       }
     )
 
@@ -440,12 +618,12 @@ setMethod(
 #' @param partition Partition Athena table (needs to be a named list or vector) for example: \code{c(var1 = "2019-20-13")}
 #' @param s3.location s3 bucket to store Athena table, must be set as a s3 uri for example ("s3://mybucket/data/").
 #'        By default s3.location is set s3 staging directory from \code{\linkS4class{AthenaConnection}} object.
-#' @param file.type What file type to store data.frame on s3, noctua currently supports ["tsv", "csv", "parquet", "json"]. Default delimited file type is "tsv", in previous versions
+#' @param file.type What file type to store data.frame on s3, noctua currently supports \code{c("tsv", "csv", "parquet", "json")}. Default delimited file type is "tsv", in previous versions
 #'                  of \code{noctua (=< 1.4.0)} file type "csv" was used as default. The reason for the change is that columns containing \code{Array/JSON} format cannot be written to
 #'                  Athena due to the separating value ",". This would cause issues with AWS Athena.
 #'                  \strong{Note:} "parquet" format is supported by the \code{arrow} package and it will need to be installed to utilise the "parquet" format.
 #'                  "json" format is supported by \code{jsonlite} package and it will need to be installed to utilise the "json" format.
-#' @param compress \code{FALSE | TRUE} To determine if to compress file.type. If file type is ["csv", "tsv"] then "gzip" compression is used, for file type "parquet"
+#' @param compress \code{FALSE | TRUE} To determine if to compress file.type. If file type is \code{c("csv", "tsv")} then "gzip" compression is used, for file type "parquet"
 #'                 "snappy" compression is used. Currently \code{noctua} doesn't support compression for "json" file type.
 #' @return \code{sqlCreateTable} returns data.frame's \code{DDL} in the \code{\link[DBI]{SQL}} format.
 #' @seealso \code{\link[DBI]{sqlCreateTable}}
@@ -484,9 +662,19 @@ NULL
 #' @rdname sqlCreateTable
 #' @export
 setMethod(
-  "sqlCreateTable", "AthenaConnection",
-  function(con, table, fields, field.types = NULL, partition = NULL, s3.location = NULL, file.type = c("tsv", "csv", "parquet", "json"),
-           compress = FALSE, ...) {
+  "sqlCreateTable",
+  "AthenaConnection",
+  function(
+    con,
+    table,
+    fields,
+    field.types = NULL,
+    partition = NULL,
+    s3.location = NULL,
+    file.type = c("tsv", "csv", "parquet", "json"),
+    compress = FALSE,
+    ...
+  ) {
     con_error_msg(con, msg = "Connection already closed.")
     stopifnot(
       is.character(table),
@@ -501,7 +689,9 @@ setMethod(
     file.type <- match.arg(file.type)
 
     # use default s3_staging directory is s3.location isn't provided
-    if (is.null(s3.location)) s3.location <- con@info$s3_staging
+    if (is.null(s3.location)) {
+      s3.location <- con@info$s3_staging
+    }
 
     ll <- db_detect(con, table)
 
@@ -510,14 +700,27 @@ setMethod(
     s3_location <- Filter(Negate(is.null), s3_location)
     s3_location <- sprintf("'s3://%s/'", paste(s3_location, collapse = "/"))
 
-    table <- paste0(quote_identifier(con, c(ll[["db.catalog"]], ll[["dbms.name"]], ll[["table"]])), collapse = ".")
+    table <- paste0(
+      quote_identifier(
+        con,
+        c(ll[["db.catalog"]], ll[["dbms.name"]], ll[["table"]])
+      ),
+      collapse = "."
+    )
 
     SQL(paste0(
-      "CREATE EXTERNAL TABLE ", table, " (\n",
-      "  ", paste(field, collapse = ",\n  "), "\n)\n",
+      "CREATE EXTERNAL TABLE ",
+      table,
+      " (\n",
+      "  ",
+      paste(field, collapse = ",\n  "),
+      "\n)\n",
       partitioned(con, partition),
-      FileType(file.type), "\n",
-      "LOCATION ", s3_location, "\n",
+      FileType(file.type),
+      "\n",
+      "LOCATION ",
+      s3_location,
+      "\n",
       header(file.type, compress)
     ))
   }
@@ -529,7 +732,11 @@ createFields <- function(con, fields, field.types) {
     fields <- vapply(fields, function(x) DBI::dbDataType(con, x), character(1))
   }
   if (!is.null(field.types)) {
-    names(field.types) <- gsub("\\.", "_", make.names(names(field.types), unique = TRUE))
+    names(field.types) <- gsub(
+      "\\.",
+      "_",
+      make.names(names(field.types), unique = TRUE)
+    )
     fields[names(field.types)] <- field.types
   }
 
@@ -537,7 +744,8 @@ createFields <- function(con, fields, field.types) {
   DIFF <- setdiff(field_names, names(fields))
   if (length(DIFF) > 0) {
     info_msg(
-      "data.frame colnames have been converted to align with Athena DDL naming convertions: \n", paste0(DIFF, collapse = ",\n")
+      "data.frame colnames have been converted to align with Athena DDL naming convertions: \n",
+      paste0(DIFF, collapse = ",\n")
     )
   }
   field_names <- quote_identifier(con, field_names)
@@ -554,9 +762,18 @@ partitioned <- function(con, obj = NULL) {
 }
 
 FileType <- function(obj) {
-  switch(obj,
-    csv = gsub("_", "", "ROW FORMAT DELIMITED\n\tFIELDS TERMINATED BY ','\n\tLINES TERMINATED BY '\\_n'"),
-    tsv = gsub("_", "", "ROW FORMAT DELIMITED\n\tFIELDS TERMINATED BY '\t'\n\tLINES TERMINATED BY '\\_n'"),
+  switch(
+    obj,
+    csv = gsub(
+      "_",
+      "",
+      "ROW FORMAT DELIMITED\n\tFIELDS TERMINATED BY ','\n\tLINES TERMINATED BY '\\_n'"
+    ),
+    tsv = gsub(
+      "_",
+      "",
+      "ROW FORMAT DELIMITED\n\tFIELDS TERMINATED BY '\t'\n\tLINES TERMINATED BY '\\_n'"
+    ),
     parquet = SQL("STORED AS PARQUET"),
     json = SQL("ROW FORMAT  serde 'org.apache.hive.hcatalog.data.JsonSerDe'")
   )
@@ -566,13 +783,15 @@ header <- function(obj, compress) {
   compress <- if (!compress) {
     ""
   } else {
-    switch(obj,
+    switch(
+      obj,
       csv = ",\n\t\t'compressionType'='gzip'",
       tsv = ",\n\t\t'compressionType'='gzip'",
       parquet = 'tblproperties ("parquet.compress"="SNAPPY")'
     )
   }
-  switch(obj,
+  switch(
+    obj,
     csv = paste0('TBLPROPERTIES ("skip.header.line.count"="1"', compress, ");"),
     tsv = paste0('TBLPROPERTIES ("skip.header.line.count"="1"', compress, ");"),
     parquet = paste0(compress, ";")
@@ -581,7 +800,8 @@ header <- function(obj, compress) {
 
 Compress <- function(file.type, compress) {
   if (compress) {
-    switch(file.type,
+    switch(
+      file.type,
       "csv" = paste(file.type, "gz", sep = "."),
       "tsv" = paste(file.type, "gz", sep = "."),
       "parquet" = paste("snappy", file.type, sep = "."),
@@ -610,7 +830,13 @@ quote_identifier <- function(conn, x, ...) {
 }
 
 # moved s3 component builder to separate helper function to allow for unit tests
-s3_upload_location <- function(con, s3.location = NULL, name = NULL, partition = NULL, append = FALSE) {
+s3_upload_location <- function(
+  con,
+  s3.location = NULL,
+  name = NULL,
+  partition = NULL,
+  append = FALSE
+) {
   # Get schema and name
   ll <- db_detect(con, name)
   schema <- ll[["dbms.name"]]
@@ -624,7 +850,12 @@ s3_upload_location <- function(con, s3.location = NULL, name = NULL, partition =
   s3_info$key <- if (s3_info$key == "") NULL else s3_info$key
 
   # formatting partitions
-  partition <- paste(names(partition), unname(partition), sep = "=", collapse = "/")
+  partition <- paste(
+    names(partition),
+    unname(partition),
+    sep = "=",
+    collapse = "/"
+  )
   partition <- if (partition == "") NULL else partition
 
   # Leave s3 location if appending to table:
@@ -649,11 +880,23 @@ s3_upload_location <- function(con, s3.location = NULL, name = NULL, partition =
 }
 
 # repair table using MSCK REPAIR TABLE for non partitioned and ALTER TABLE for partitioned tables
-repair_table <- function(con, name, partition = NULL, s3.location = NULL, append = FALSE) {
+repair_table <- function(
+  con,
+  name,
+  partition = NULL,
+  s3.location = NULL,
+  append = FALSE
+) {
   ll <- db_detect(con, name)
 
   # format table name for special characters
-  table <- paste0(quote_identifier(con, c(ll[["db.catalog"]], ll[["dbms.name"]], ll[["table"]])), collapse = ".")
+  table <- paste0(
+    quote_identifier(
+      con,
+      c(ll[["db.catalog"]], ll[["dbms.name"]], ll[["table"]])
+    ),
+    collapse = "."
+  )
 
   if (is.null(partition)) {
     query <- SQL(paste0("MSCK REPAIR TABLE ", table))
@@ -670,16 +913,25 @@ repair_table <- function(con, name, partition = NULL, s3.location = NULL, append
     partition <- paste0(partition_names, " = ", partition, collapse = ", ")
     s3_location <- dbQuoteString(con, s3_location)
 
-    query <- SQL(paste0("ALTER TABLE ", table, " ADD IF NOT EXISTS\nPARTITION (", partition, ")\nLOCATION ", s3_location))
+    query <- SQL(paste0(
+      "ALTER TABLE ",
+      table,
+      " ADD IF NOT EXISTS\nPARTITION (",
+      partition,
+      ")\nLOCATION ",
+      s3_location
+    ))
     res <- dbSendQuery(con, query, unload = FALSE)
     poll(res)
     on.exit(dbClearResult(res))
     # If query failed, due to glue permissions default back to msck repair table
     if (res@info[["Status"]] == "FAILED") {
-      if (grepl(
-        ".*glue.*BatchCreatePartition.*AccessDeniedException",
-        res@info[["StateChangeReason"]]
-      )) {
+      if (
+        grepl(
+          ".*glue.*BatchCreatePartition.*AccessDeniedException",
+          res@info[["StateChangeReason"]]
+        )
+      ) {
         query <- SQL(paste0("MSCK REPAIR TABLE ", table))
         rs <- dbExecute(con, query, unload = FALSE)
         return(dbClearResult(rs))
