@@ -36,10 +36,10 @@ AthenaListObjectTypes <- function(connection) {
 AthenaListObjectTypes.default <- function(connection) {
   # slurp all the objects in the schema so we can determine the correct
   # object hierarchy
-  
+
   # all schema contain tables, at a minimum
   obj_types <- list(table = list(contains = "data"))
-  
+
   # see if we have views too
   table_types <- AthenaTableTypes(connection)
   if (any(grepl("VIEW", table_types))) {
@@ -51,35 +51,44 @@ AthenaListObjectTypes.default <- function(connection) {
   if (length(schemas) > 0) {
     obj_types <- list(schema = list(contains = obj_types))
   }
-  
+
   catalogs <- list_catalogs(connection@ptr$Athena)
   # check for multiple catalogs
   if (length(catalogs) > 0) {
     obj_types <- list(catalog = list(contains = obj_types))
   }
-  
+
   obj_types
 }
 
-# List objects in a connection.
-#
-# Lists all of the objects in the connection, or all the objects which have
-# specific attributes.
-#
-# When used without parameters, this function returns all of the objects known
-# by the connection. Any parameters passed will filter the list to only objects
-# which have the given attributes; for instance, passing \code{schema = "foo"}
-# will return only objects matching the schema \code{foo}.
-#
-# @param connection A connection object, as returned by `dbConnect()`.
-# @param ... Attributes to filter by.
-# @return A data frame with \code{name} and \code{type} columns, listing the
-#   objects.
+#' List objects in a connection.
+#'
+#' Lists all of the objects in the connection, or all the objects which have
+#' specific attributes.
+#'
+#' When used without parameters, this function returns all of the objects known
+#' by the connection. Any parameters passed will filter the list to only objects
+#' which have the given attributes; for instance, passing \code{schema = "foo"}
+#' will return only objects matching the schema \code{foo}.
+#'
+#' @param connection A connection object, as returned by `dbConnect()`.
+#' @param ... Attributes to filter by.
+#' @return A data frame with \code{name} and \code{type} columns, listing the
+#'   objects.
+#' @keywords internal
+#' @export
+AthenaListObjects <- function(connection, ...) {
+  UseMethod("AthenaListObjects")
+}
 
-AthenaListObjects <- function(connection, ...) {UseMethod("AthenaListObjects")}
-
-AthenaListObjects.AthenaConnection <- function(connection, catalog = NULL, schema = NULL, name = NULL, ...) {
-  
+#'@export
+AthenaListObjects.AthenaConnection <- function(
+  connection,
+  catalog = NULL,
+  schema = NULL,
+  name = NULL,
+  ...
+) {
   # if no catalog was supplied but this database has catalogs, return a list of
   # catalogs
   if (is.null(catalog)) {
@@ -90,10 +99,11 @@ AthenaListObjects.AthenaConnection <- function(connection, catalog = NULL, schem
           name = catalogs,
           type = rep("catalog", times = length(catalogs)),
           stringsAsFactors = FALSE
-        ))
+        )
+      )
     }
   }
-  
+
   # if no schema was supplied but this catalog has schema, return a list of
   # schema
   if (is.null(schema)) {
@@ -104,11 +114,17 @@ AthenaListObjects.AthenaConnection <- function(connection, catalog = NULL, schem
           name = schema,
           type = rep("schema", times = length(schema)),
           stringsAsFactors = FALSE
-        ))
+        )
+      )
     }
   }
-  
-  objs <- AthenaTableTypes(connection, catalog = catalog, schema = schema, name = name)
+
+  objs <- AthenaTableTypes(
+    connection,
+    catalog = catalog,
+    schema = schema,
+    name = name
+  )
   # just return a list of the objects and their types, possibly filtered by the
   # options above
   data.frame(
@@ -133,11 +149,14 @@ AthenaListObjects.AthenaConnection <- function(connection, catalog = NULL, schem
 
 # given a connection, returns its "host name" (a unique string which identifies it)
 computeHostName <- function(connection) {
-  paste(collapse = "_",c(
-    connection@info$profile_name,
-    "Athena",
-    connection@info$region_name
-  ))
+  paste(
+    collapse = "_",
+    c(
+      connection@info$profile_name,
+      "Athena",
+      connection@info$region_name
+    )
+  )
 }
 
 computeDisplayName <- function(connection) {
@@ -146,37 +165,39 @@ computeDisplayName <- function(connection) {
 
 # selects the table or view from arguments
 validateObjectName <- function(table, view) {
-  
   # Error if both table and view are passed
   if (!is.null(table) && !is.null(view)) {
     stop("`table` and `view` can not both be used", call. = FALSE)
   }
-  
+
   # Error if neither table and view are passed
   if (is.null(table) && is.null(view)) {
     stop("`table` and `view` can not both be `NULL`", call. = FALSE)
   }
-  
+
   table %||% view
 }
 
 AthenaListColumns <- function(connection, ...) UseMethod("AthenaListColumns")
 
-AthenaListColumns.AthenaConnection <- function(connection,
-                                               table = NULL,
-                                               view = NULL,
-                                               catalog = NULL,
-                                               schema = NULL,
-                                               ...) {
+#' @export
+AthenaListColumns.AthenaConnection <- function(
+  connection,
+  table = NULL,
+  view = NULL,
+  catalog = NULL,
+  schema = NULL,
+  ...
+) {
   if (dbIsValid(connection)) {
     athena <- connection@ptr$Athena
-    
+
     output <- athena$get_table_metadata(
       CatalogName = catalog,
       DatabaseName = schema,
       TableName = table %||% view
     )$TableMetadata
-    
+
     col_names <- sapply(output$Columns, ColMeta)
     partition <- unlist(sapply(output$PartitionKeys, ColMeta))
 
@@ -191,18 +212,24 @@ AthenaListColumns.AthenaConnection <- function(connection,
   }
 }
 
-AthenaTableTypes <- function(connection, catalog = NULL, schema = NULL, name = NULL, ...) {
+AthenaTableTypes <- function(
+  connection,
+  catalog = NULL,
+  schema = NULL,
+  name = NULL,
+  ...
+) {
   con_error_msg(connection, "Connection already closed.")
   athena <- connection@ptr$Athena
-  
+
   if (is.null(catalog)) {
     catalog <- list_catalogs(athena)
   }
-  
+
   if (is.null(schema)) {
     schema <- unlist(lapply(catalog, function(ct) list_schemas(athena, ct)))
   }
-  
+
   if (is.null(name)) {
     cat_filter <- ""
     db_filter <- ""
@@ -244,35 +271,49 @@ AthenaDatabase <- function(connection, catalog, ...) {
   return(unlist(list_schemas(athena, catalog)))
 }
 
-# Preview the data in an object.
-#
-# Return the data inside an object as a data frame.
-#
-# The object to previewed must be specified as one of the arguments
-# (e.g. \code{table = "employees"}); depending on the driver and underlying
-# data store, additional specification arguments may be required.
-#
-# @param connection A connection object, as returned by `dbConnect()`.
-# @param rowLimit The maximum number of rows to display.
-# @param ... Parameters specifying the object.
-# @return A data frame containing the data in the object.
+#' Preview the data in an object.
+#'
+#' Return the data inside an object as a data frame.
+#'
+#' The object to previewed must be specified as one of the arguments
+#' (e.g. \code{table = "employees"}); depending on the driver and underlying
+#' data store, additional specification arguments may be required.
+#'
+#' @param connection A connection object, as returned by `dbConnect()`.
+#' @param rowLimit The maximum number of rows to display.
+#' @param ... Parameters specifying the object.
+#' @return A data frame containing the data in the object.
+#' @keywords internal
+#' @export
+AthenaPreviewObject <- function(connection, rowLimit, ...) {
+  UseMethod("AthenaPreviewObject")
+}
 
-AthenaPreviewObject <- function(connection, rowLimit, ...) UseMethod("AthenaPreviewObject")
+#' @export
+AthenaPreviewObject.AthenaConnection <- function(
+  connection,
+  rowLimit,
+  table = NULL,
+  view = NULL,
+  catalog = NULL,
+  schema = NULL,
+  ...
+) {
+  # extract object name from arguments
+  name <- validateObjectName(table, view)
 
-AthenaPreviewObject.AthenaConnection <- function(connection, rowLimit, table = NULL, 
-                                                 view = NULL, catalog = NULL, schema = NULL, ...) {
-    # extract object name from arguments
-    name <- validateObjectName(table, view)
-    
-    # prepend schema if specified
-    if (!is.null(schema)) {
-      name <- paste(dbQuoteIdentifier(connection, schema),
-                    dbQuoteIdentifier(connection, name), sep = ".")
-    }
-    
-    dbGetQuery(connection, paste("SELECT * FROM", name, "LIMIT", rowLimit))
+  # prepend schema if specified
+  if (!is.null(schema)) {
+    name <- paste(
+      dbQuoteIdentifier(connection, schema),
+      dbQuoteIdentifier(connection, name),
+      sep = "."
+    )
   }
 
+  dbGetQuery(connection, paste("SELECT * FROM", name, "LIMIT", rowLimit))
+}
+
 # Get an icon representing a connection.
 #
 # Return the path on disk to an icon representing a connection.
@@ -305,7 +346,7 @@ AthenaConnectionIcon <- function(connection) {
 
 AthenaConnectionActions <- function(connection) {
   icons <- system.file(file.path("icons"), package = "noctua")
-  
+
   actions <- list(
     "Athena" = list(
       icon = file.path(icons, "athena-logo.png"),
@@ -314,7 +355,7 @@ AthenaConnectionActions <- function(connection) {
       }
     )
   )
-  
+
   if (exists(".rs.api.documentNew")) {
     documentNew <- get(".rs.api.documentNew")
     actions <- c(
@@ -325,30 +366,36 @@ AthenaConnectionActions <- function(connection) {
           callback = function() {
             varname <- Filter(
               function(e) identical(get(e, envir = .GlobalEnv), connection),
-              ls(envir = .GlobalEnv))
-            
+              ls(envir = .GlobalEnv)
+            )
+
             tables <- dbListTables(connection)
-            
+
             contents <- paste(
               paste("-- !preview conn=", varname, sep = ""),
               "",
-              if (length(tables) > 0)
-                paste("SELECT * FROM \"", tables[[1]], "\"\nLIMIT 100", 
-                      "\n\n-- Note: Please utilise LIMIT to restrict Data Scanned by AWS Athena",
-                      sep = "")
-              else
-                "SELECT 1",
+              if (length(tables) > 0) {
+                paste(
+                  "SELECT * FROM \"",
+                  tables[[1]],
+                  "\"\nLIMIT 100",
+                  "\n\n-- Note: Please utilise LIMIT to restrict Data Scanned by AWS Athena",
+                  sep = ""
+                )
+              } else {
+                "SELECT 1"
+              },
               "",
               sep = "\n"
             )
-            
+
             documentNew("sql", contents, row = 2, column = 15, execute = FALSE)
           }
         )
       )
     )
   }
-  
+
   actions <- c(
     actions,
     list(
@@ -360,19 +407,21 @@ AthenaConnectionActions <- function(connection) {
       )
     )
   )
-  
+
   actions
 }
 
 on_connection_closed <- function(con) {
   # make sure we have an observer
   observer <- getOption("connectionObserver")
-  if (is.null(observer))
+  if (is.null(observer)) {
     return(invisible(NULL))
-  
-  if(!athena_option_env$rstudio_conn_tab)
+  }
+
+  if (!athena_option_env$rstudio_conn_tab) {
     return(invisible(NULL))
-  
+  }
+
   type <- "Athena"
   host <- computeHostName(con)
   observer$connectionClosed(type, host)
@@ -381,12 +430,14 @@ on_connection_closed <- function(con) {
 on_connection_updated <- function(con, hint) {
   # make sure we have an observer
   observer <- getOption("connectionObserver")
-  if (is.null(observer))
+  if (is.null(observer)) {
     return(invisible(NULL))
-  
-  if(!athena_option_env$rstudio_conn_tab)
+  }
+
+  if (!athena_option_env$rstudio_conn_tab) {
     return(invisible(NULL))
-  
+  }
+
   type <- "Athena"
   host <- computeHostName(con)
   observer$connectionUpdated(type, host, hint = hint)
@@ -395,72 +446,77 @@ on_connection_updated <- function(con, hint) {
 on_connection_opened <- function(connection) {
   # make sure we have an observer
   observer <- getOption("connectionObserver")
-  if (is.null(observer))
+  if (is.null(observer)) {
     return(invisible(NULL))
-  
-  if(!athena_option_env$rstudio_conn_tab)
+  }
+
+  if (!athena_option_env$rstudio_conn_tab) {
     return(invisible(NULL))
-  
+  }
+
   # find an icon for this DBMS
   icon <- AthenaConnectionIcon(connection)
-  
+
   # let observer know that connection has opened
   observer$connectionOpened(
     type = "Athena",
-    
+
     # name displayed in connection pane
     displayName = computeDisplayName(connection),
-    
+
     # host key
     host = computeHostName(connection),
-    
+
     # icon for connection
     icon = icon,
-    
+
     # connection code
-    connectCode = paste(c("library(DBI)", "con <- dbConnect(noctua::athena())"),collapse = "\n"),
-    
+    connectCode = paste(
+      c("library(DBI)", "con <- dbConnect(noctua::athena())"),
+      collapse = "\n"
+    ),
+
     # disconnection code
     disconnect = function() {
       dbDisconnect(connection)
     },
-    
-    listObjectTypes = function () {
+
+    listObjectTypes = function() {
       AthenaListObjectTypes(connection)
     },
-    
+
     # table enumeration code
     listObjects = function(...) {
       AthenaListObjects(connection, ...)
     },
-    
+
     # column enumeration code
     listColumns = function(...) {
       AthenaListColumns(connection, ...)
     },
-    
+
     # table preview code
     previewObject = function(rowLimit, ...) {
       AthenaPreviewObject(connection, rowLimit, ...)
     },
-    
+
     # other actions that can be executed on this connection
     actions = AthenaConnectionActions(connection),
-    
+
     # raw connection object
     connectionObject = connection
   )
 }
-# nocov end 
+# nocov end
 
 TblMeta <- function(x) {
-  tbl_type <- if(length(x$TableType)) x$TableType else ""
+  tbl_type <- if (length(x$TableType)) x$TableType else ""
   names(tbl_type) <- x$Name
   tbl_type
 }
 
-ColMeta <- function(x){
-  col_type <- if(length(x$Type)) x$Type else ""
+ColMeta <- function(x) {
+  col_type <- if (length(x$Type)) x$Type else ""
   names(col_type) <- x$Name
   col_type
 }
