@@ -4,7 +4,7 @@ split_s3_uri <- function(uri) {
   path <- gsub("^s3://", "", uri)
   list(
     bucket = gsub("/.*$", "", path),
-    key = gsub("^[a-z0-9][a-z0-9\\.-]+[a-z0-9]/", "", path)
+    key = gsub("^[a-z0-9][a-z0-9\\.-]+[a-z0-9](/|$)", "", path)
   )
 }
 
@@ -30,15 +30,34 @@ poll <- function(res) {
   class_poll <- res@connection@info[["poll_interval"]]
   while (TRUE) {
     poll_interval <- class_poll %||% rand_poll()
-    tryCatch(query_execution <- res@connection@ptr$Athena$get_query_execution(QueryExecutionId = res@info$QueryExecutionId))
-    if (query_execution$QueryExecution$Status$State %in% c("SUCCEEDED", "FAILED", "CANCELLED")) {
+    tryCatch(
+      query_execution <- res@connection@ptr$Athena$get_query_execution(
+        QueryExecutionId = res@info$QueryExecutionId
+      )
+    )
+    if (
+      query_execution$QueryExecution$Status$State %in%
+        c("SUCCEEDED", "FAILED", "CANCELLED")
+    ) {
       # update info environment
-      res@info[["Status"]] <- query_execution[["QueryExecution"]][["Status"]][["State"]]
-      res@info[["StateChangeReason"]] <- query_execution[["QueryExecution"]][["Status"]][["StateChangeReason"]]
-      res@info[["StatementType"]] <- query_execution[["QueryExecution"]][["StatementType"]]
-      res@info[["WorkGroup"]] <- query_execution[["QueryExecution"]][["WorkGroup"]]
-      res@info[["OutputLocation"]] <- query_execution[["QueryExecution"]][["ResultConfiguration"]][["OutputLocation"]]
-      res@info[["Statistics"]] <- query_execution[["QueryExecution"]][["Statistics"]]
+      res@info[["Status"]] <- query_execution[["QueryExecution"]][["Status"]][[
+        "State"
+      ]]
+      res@info[["StateChangeReason"]] <- query_execution[["QueryExecution"]][[
+        "Status"
+      ]][["StateChangeReason"]]
+      res@info[["StatementType"]] <- query_execution[["QueryExecution"]][[
+        "StatementType"
+      ]]
+      res@info[["WorkGroup"]] <- query_execution[["QueryExecution"]][[
+        "WorkGroup"
+      ]]
+      res@info[["OutputLocation"]] <- query_execution[["QueryExecution"]][[
+        "ResultConfiguration"
+      ]][["OutputLocation"]]
+      res@info[["Statistics"]] <- query_execution[["QueryExecution"]][[
+        "Statistics"
+      ]]
       break
     } else {
       Sys.sleep(poll_interval)
@@ -73,6 +92,7 @@ resource_active <- function(dbObj) {
 }
 
 # checks is dbObj is active
+#' @export
 resource_active.AthenaConnection <- function(dbObj) {
   if (length(dbObj@ptr) != 0) {
     return(TRUE)
@@ -81,9 +101,12 @@ resource_active.AthenaConnection <- function(dbObj) {
   }
 }
 
+#' @export
 resource_active.AthenaResult <- function(dbObj) {
-  if (length(dbObj@info) != 0 &&
-    length(dbObj@connection@ptr) != 0) {
+  if (
+    length(dbObj@info) != 0 &&
+      length(dbObj@connection@ptr) != 0
+  ) {
     return(TRUE)
   } else {
     return(FALSE)
@@ -97,25 +120,35 @@ ResultConfiguration <- function(conn) {
 
   # adding EncryptionConfiguration to ResultConfiguration
   if (!is.null(conn@info$encryption_option)) {
-    EncryptionConfiguration <- list("EncryptionOption" = conn@info$encryption_option)
+    EncryptionConfiguration <- list(
+      "EncryptionOption" = conn@info$encryption_option
+    )
     EncryptionConfiguration["KmsKey"] <- conn@info$kms_key
-    ResultConfiguration["EncryptionConfiguration"] <- list(EncryptionConfiguration)
+    ResultConfiguration["EncryptionConfiguration"] <- list(
+      EncryptionConfiguration
+    )
   }
 
   ResultConfiguration
 }
 
 # set up work group configuration
-work_group_config <- function(conn,
-                              EnforceWorkGroupConfiguration = FALSE,
-                              PublishCloudWatchMetricsEnabled = FALSE,
-                              BytesScannedCutoffPerQuery = 10000000L) {
+work_group_config <- function(
+  conn,
+  EnforceWorkGroupConfiguration = FALSE,
+  PublishCloudWatchMetricsEnabled = FALSE,
+  BytesScannedCutoffPerQuery = 10000000L
+) {
   config <- list()
   ResultConfiguration <- list(OutputLocation = conn@info$s3_staging)
   if (!is.null(conn@info$encryption_option)) {
-    EncryptionConfiguration <- list("EncryptionOption" = conn@info$encryption_option)
+    EncryptionConfiguration <- list(
+      "EncryptionOption" = conn@info$encryption_option
+    )
     EncryptionConfiguration["KmsKey"] <- conn@info$kms_key
-    ResultConfiguration["EncryptionConfiguration"] <- list(EncryptionConfiguration)
+    ResultConfiguration["EncryptionConfiguration"] <- list(
+      EncryptionConfiguration
+    )
   }
   config["ResultConfiguration"] <- list(ResultConfiguration)
   config["EnforceWorkGroupConfiguration"] <- EnforceWorkGroupConfiguration
@@ -126,27 +159,50 @@ work_group_config <- function(conn,
 
 # set up work group configuration update
 work_group_config_update <-
-  function(conn,
-           RemoveOutputLocation = FALSE,
-           EnforceWorkGroupConfiguration = FALSE,
-           PublishCloudWatchMetricsEnabled = FALSE,
-           BytesScannedCutoffPerQuery = 10000000L) {
+  function(
+    conn,
+    RemoveOutputLocation = FALSE,
+    EnforceWorkGroupConfiguration = FALSE,
+    PublishCloudWatchMetricsEnabled = FALSE,
+    BytesScannedCutoffPerQuery = 10000000L,
+    EngineVersion = list()
+  ) {
     ConfigurationUpdates <- list()
     ResultConfigurationUpdates <- list(
       OutputLocation = conn@info$s3_staging,
       RemoveOutputLocation = RemoveOutputLocation
     )
     if (!is.null(conn@info$encryption_option)) {
-      EncryptionConfiguration <- list("EncryptionOption" = conn@info$encryption_option)
+      EncryptionConfiguration <- list(
+        "EncryptionOption" = conn@info$encryption_option
+      )
       EncryptionConfiguration["KmsKey"] <- conn@info$kms_key
-      ResultConfigurationUpdates["EncryptionConfiguration"] <- list(EncryptionConfiguration)
+      ResultConfigurationUpdates["EncryptionConfiguration"] <- list(
+        EncryptionConfiguration
+      )
     }
 
-    ConfigurationUpdates["EnforceWorkGroupConfiguration"] <- EnforceWorkGroupConfiguration
-    ConfigurationUpdates["ResultConfigurationUpdates"] <- list(ResultConfigurationUpdates)
-    ConfigurationUpdates["PublishCloudWatchMetricsEnabled"] <- PublishCloudWatchMetricsEnabled
-    ConfigurationUpdates["BytesScannedCutoffPerQuery"] <- BytesScannedCutoffPerQuery
+    ConfigurationUpdates[
+      "EnforceWorkGroupConfiguration"
+    ] <- EnforceWorkGroupConfiguration
+    ConfigurationUpdates["ResultConfigurationUpdates"] <- list(
+      ResultConfigurationUpdates
+    )
+    ConfigurationUpdates[
+      "PublishCloudWatchMetricsEnabled"
+    ] <- PublishCloudWatchMetricsEnabled
+    ConfigurationUpdates[
+      "BytesScannedCutoffPerQuery"
+    ] <- BytesScannedCutoffPerQuery
 
+    if (
+      any(
+        names(EngineVersion) %in%
+          c("SelectedEngineVersion", "EffectiveEngineVersion")
+      )
+    ) {
+      ConfigurationUpdates["EngineVersion"] <- EngineVersion
+    }
     ConfigurationUpdates
   }
 
@@ -169,10 +225,12 @@ get_aws_env <- function(x) {
   }
 }
 
-`%||%` <- function(x, y) if (is.null(x)) {
-  return(y)
-} else {
-  return(x)
+`%||%` <- function(x, y) {
+  if (is.null(x)) {
+    return(y)
+  } else {
+    return(x)
+  }
 }
 
 # time check warning when connection will expire soon
@@ -183,7 +241,14 @@ time_check <- function(x) {
   m <- x %/% 60
   s <- round(x %% 60, 0)
   if (m < 15) {
-    warning("Athena Connection will expire in ", time_format(m), ":", time_format(s), " (mm:ss)", call. = F)
+    warning(
+      "Athena Connection will expire in ",
+      time_format(m),
+      ":",
+      time_format(s),
+      " (mm:ss)",
+      call. = F
+    )
   }
 }
 
@@ -192,7 +257,11 @@ time_format <- function(x) if (x < 10) paste0(0, x) else x
 # get parent pkg function and method
 pkg_method <- function(fun, pkg) {
   if (!requireNamespace(pkg, quietly = TRUE)) {
-    stop(fun, " requires the ", pkg, " package, please install it first and try again",
+    stop(
+      fun,
+      " requires the ",
+      pkg,
+      " package, please install it first and try again",
       call. = F
     )
   }
@@ -201,11 +270,13 @@ pkg_method <- function(fun, pkg) {
 }
 
 # set credentials
-cred_set <- function(aws_access_key_id,
-                     aws_secret_access_key,
-                     aws_session_token,
-                     profile_name,
-                     region_name) {
+cred_set <- function(
+  aws_access_key_id,
+  aws_secret_access_key,
+  aws_session_token,
+  profile_name,
+  region_name
+) {
   add_list <- function(x) if (length(x) == 0) NULL else x
   config <- list()
   credentials <- list()
@@ -225,12 +296,18 @@ cred_set <- function(aws_access_key_id,
 
 # Format DataScannedInBytes to a more readable format:
 data_scanned <- function(x) {
-    base <- 1024
-    units_map <- c("B", "KB", "MB", "GB", "TB", "PB")
-    power <- if (x <= 0) 0L else min(as.integer(log(x, base = base)), length(units_map) - 1L)
-    unit <- units_map[power + 1L]
-    if (power == 0) unit <- "Bytes"
-    paste(round(x / base^power, digits = 2), unit)
+  base <- 1024
+  units_map <- c("B", "KB", "MB", "GB", "TB", "PB")
+  power <- if (x <= 0) {
+    0L
+  } else {
+    min(as.integer(log(x, base = base)), length(units_map) - 1L)
+  }
+  unit <- units_map[power + 1L]
+  if (power == 0) {
+    unit <- "Bytes"
+  }
+  paste(round(x / base^power, digits = 2), unit)
 }
 
 # caching function to added metadata to cache data.table
@@ -246,7 +323,11 @@ cache_query <- function(res) {
       "WorkGroup" = res@info[["WorkGroup"]],
       "UnloadDir" = res@info[["UnloadDir"]] %||% character(1)
     )
-    new_query <- fsetdiff(cache_append, athena_option_env[["cache_dt"]], all = TRUE)
+    new_query <- fsetdiff(
+      cache_append,
+      athena_option_env[["cache_dt"]],
+      all = TRUE
+    )
     athena_option_env$cache_dt <- head(
       rbind(new_query, athena_option_env[["cache_dt"]]),
       athena_option_env[["cache_size"]]
@@ -274,15 +355,11 @@ check_cache <- function(query, work_group) {
 retry_api_call <- function(expr) {
   # if number of retries is equal to 0 then retry is skipped
   if (athena_option_env$retry == 0) {
-    resp <- tryCatch(eval.parent(substitute(expr)),
-      error = function(e) e
-    )
+    resp <- tryCatch(eval.parent(substitute(expr)), error = function(e) e)
   }
 
   for (i in seq_len(athena_option_env$retry)) {
-    resp <- tryCatch(eval.parent(substitute(expr)),
-      error = function(e) e
-    )
+    resp <- tryCatch(eval.parent(substitute(expr)), error = function(e) e)
 
     if (inherits(resp, "error")) {
       # stop retry if statement is an invalid request
@@ -292,7 +369,12 @@ retry_api_call <- function(expr) {
 
       backoff_len <- runif(n = 1, min = 0, max = (2^i - 1))
 
-      info_msg(resp, "Request failed. Retrying in ", round(backoff_len, 1), " seconds...")
+      info_msg(
+        resp,
+        "Request failed. Retrying in ",
+        round(backoff_len, 1),
+        " seconds..."
+      )
 
       Sys.sleep(backoff_len)
     } else {
@@ -300,16 +382,24 @@ retry_api_call <- function(expr) {
     }
   }
 
-  if (inherits(resp, "error")) stop(resp)
+  if (inherits(resp, "error")) {
+    stop(resp)
+  }
 
   return(resp)
 }
 
 
 # Create table With parameters
-ctas_sql_with <- function(partition = NULL, s3.location = NULL, file.type = "NULL", compress = TRUE) {
+ctas_sql_with <- function(
+  partition = NULL,
+  s3.location = NULL,
+  file.type = "NULL",
+  compress = TRUE
+) {
   if (file.type != "NULL" || !is.null(s3.location) || !is.null(partition)) {
-    FILE <- switch(file.type,
+    FILE <- switch(
+      file.type,
       "csv" = "format = 'TEXTFILE',\nfield_delimiter = ','",
       "tsv" = "format = 'TEXTFILE',\nfield_delimiter = '\t'",
       "parquet" = "format = 'PARQUET'",
@@ -326,7 +416,8 @@ ctas_sql_with <- function(partition = NULL, s3.location = NULL, file.type = "NUL
           call. = FALSE
         )
       }
-      COMPRESSION <- switch(file.type,
+      COMPRESSION <- switch(
+        file.type,
         "parquet" = ",\nparquet_compression = 'SNAPPY'",
         "orc" = ",\norc_compression = 'SNAPPY'",
         ""
@@ -364,7 +455,9 @@ ctas_sql_with <- function(partition = NULL, s3.location = NULL, file.type = "NUL
 jsonlite_check <- function(method) {
   if (method == "auto") {
     if (!nzchar(system.file(package = "jsonlite"))) {
-      info_msg("`jsonlite` has not been detected, AWS Athena `json` data types will be returned as `character`.")
+      info_msg(
+        "`jsonlite` has not been detected, AWS Athena `json` data types will be returned as `character`."
+      )
       method <- "character"
     }
   }
@@ -382,7 +475,9 @@ list_catalogs <- function(client) {
     token <- response[["NextToken"]]
     i <- i + 1
   }
-  return(as.character(do.call(rbind, unlist(data_list, recursive = F))[, "CatalogName"]))
+  return(as.character(do.call(rbind, unlist(data_list, recursive = F))[,
+    "CatalogName"
+  ]))
 }
 
 # list database
@@ -396,7 +491,9 @@ list_schemas <- function(client, catalog) {
     token <- response[["NextToken"]]
     i <- i + 1
   }
-  return(as.character(do.call(rbind, unlist(data_list, recursive = F))[, "Name"]))
+  return(as.character(do.call(rbind, unlist(data_list, recursive = F))[,
+    "Name"
+  ]))
 }
 
 # wrapper to return connection error when disconnected
@@ -409,7 +506,8 @@ con_error_msg <- function(obj, msg = "Connection already closed.") {
 # wrapper to detect database for paws api calls.
 db_detect <- function(conn, name) {
   parts <- strsplit(name, ".", fixed = T)[[1]]
-  db_components <- switch(length(parts),
+  db_components <- switch(
+    length(parts),
     list(conn@info[["db.catalog"]], conn@info[["dbms.name"]], parts),
     as.list(c(conn@info[["db.catalog"]], parts)),
     as.list(parts)
@@ -441,9 +539,14 @@ set_endpoints <- function(endpoint_override) {
   }
   if (is.list(endpoint_override)) {
     if (length(names(endpoint_override)) == 0) {
-      stop("endpoint_override needed to be a named list or character", call. = F)
+      stop(
+        "endpoint_override needed to be a named list or character",
+        call. = F
+      )
     }
-    if (any(!(tolower(names(endpoint_override)) %in% c("athena", "s3", "glue")))) {
+    if (
+      any(!(tolower(names(endpoint_override)) %in% c("athena", "s3", "glue")))
+    ) {
       stop(
         "The named list can only have the following names ['athena', 's3', glue']",
         call. = F
@@ -462,22 +565,23 @@ str_count <- function(str, pattern) {
   return(lengths(regmatches(str, gregexpr(pattern, str))))
 }
 
-db_quote_identifier <- function (x, ...) {
-  if (is(x, "SQL")) 
+db_quote_identifier <- function(x, ...) {
+  if (is(x, "SQL")) {
     return(x)
+  }
   if (is(x, "Id")) {
     return(SQL(paste0(x@name, collapse = ".")))
   }
-  if (!is.character(x)) 
+  if (!is.character(x)) {
     stop("x must be character or SQL", call. = FALSE)
+  }
   if (any(is.na(x))) {
     stop("Cannot pass NA to dbQuoteIdentifier()", call. = FALSE)
   }
   x <- gsub("\"", "\"\"", enc2utf8(x))
   if (length(x) == 0L) {
     SQL(character(), names = names(x))
-  }
-  else {
+  } else {
     SQL(paste("\"", x, "\"", sep = ""), names = names(x))
   }
 }
